[alsa-devel] [PATCH 06/10] ASoC: rsnd: INT_ENABLE is needed only Gen2

Kuninori Morimoto kuninori.morimoto.gx at gmail.com
Fri Dec 20 04:28:19 CET 2013


From: Kuninori Morimoto <kuninori.morimoto.gx at renesas.com>

INT_ENABLE is needed only Gen2.
rsnd_mod_write() do nothing on Gen1, but it is confusable.

Signed-off-by: Kuninori Morimoto <kuninori.morimoto.gx at renesas.com>
---
 sound/soc/sh/rcar/rsnd.h |    2 +-
 sound/soc/sh/rcar/ssi.c  |    5 +++--
 2 files changed, 4 insertions(+), 3 deletions(-)

diff --git a/sound/soc/sh/rcar/rsnd.h b/sound/soc/sh/rcar/rsnd.h
index a14bc92..3774dfc 100644
--- a/sound/soc/sh/rcar/rsnd.h
+++ b/sound/soc/sh/rcar/rsnd.h
@@ -40,7 +40,7 @@ enum rsnd_reg {
 	RSND_REG_SSI_MODE0,
 	RSND_REG_SSI_MODE1,
 	RSND_REG_BUSIF_MODE,
-	RSND_REG_INT_ENABLE,
+	RSND_REG_INT_ENABLE,		/* for Gen2 */
 	RSND_REG_SRC_ADINR,
 
 	/* ADG */
diff --git a/sound/soc/sh/rcar/ssi.c b/sound/soc/sh/rcar/ssi.c
index 6b1f501..98a3de0 100644
--- a/sound/soc/sh/rcar/ssi.c
+++ b/sound/soc/sh/rcar/ssi.c
@@ -457,8 +457,9 @@ static int rsnd_ssi_pio_start(struct rsnd_mod *mod,
 	/* enable PIO IRQ */
 	ssi->cr_etc = UIEN | OIEN | DIEN;
 
-	/* enable PIO interrupt */
-	rsnd_mod_write(&ssi->mod, INT_ENABLE, 0x0f000000);
+	/* enable PIO interrupt if gen2 */
+	if (rsnd_is_gen2(priv))
+		rsnd_mod_write(&ssi->mod, INT_ENABLE, 0x0f000000);
 
 	rsnd_ssi_hw_start(ssi, rdai, io);
 
-- 
1.7.9.5



More information about the Alsa-devel mailing list